%% Perform growth phenotype predictions
[Result,Data] = AnalyzeModels();

%% Write results to file for convenient overview
FID = fopen('Table_Fig5.tsv','w+');
format = [repmat('%s\t',1,6) '%s\n'];
fprintf(FID,format,'Organism','Model type','Biomass','Sensitivity','Specificity','Accuracy','MCC');
format = [repmat('%s\t',1,3) repmat('%.2f\t',1,3) '%.2f\n'];

%B.subtilis
type = {'iGSM','iGSM','BCM','BCM','RCM','RCM'};
biomass = repmat({'iBsu1103','iYO844'},1,3);

for i=1:6
    sens = Result.BsubtilisTests.Sensitivity(i);
    spec = Result.BsubtilisTests.Specificity(i);
    acc = Result.BsubtilisTests.Accuracy(i);
    mcc = Result.BsubtilisTests.MCC(i);
    
    fprintf(FID,format,'B. subtilis',type{i},biomass{i},sens,spec,acc,mcc);
end

%P. putida
type = {'iGSM','iGSM','BCM','BCM','RCM','RCM'};
biomass = repmat({'iJN746','iJP962'},1,3);

for i=1:6
    sens = Result.PputidaTests.Sensitivity(i);
    spec = Result.PputidaTests.Specificity(i);
    acc = Result.PputidaTests.Accuracy(i);
    mcc = Result.PputidaTests.MCC(i);
    
    fprintf(FID,format,'P. putida',type{i},biomass{i},sens,spec,acc,mcc);
end

%M. tuberculosis
type = {'iGSM','BCM','RCM'};
biomass = repmat({'iNJ661'},1,3);

for i=1:3
    sens = Result.MtuberculosisTests.Sensitivity(i);
    spec = Result.MtuberculosisTests.Specificity(i);
    acc = Result.MtuberculosisTests.Accuracy(i);
    mcc = Result.MtuberculosisTests.MCC(i);
    
    fprintf(FID,format,'M. tuberculosis',type{i},biomass{i},sens,spec,acc,mcc);
end

%S. cerevisiae
type = {'iGSM','iGSM','BCM','BCM','RCM','RCM'};
biomass = repmat({'iND750','iMM904'},1,3);

for i=1:6
    sens = Result.ScerevisiaeTests.Sensitivity(i);
    spec = Result.ScerevisiaeTests.Specificity(i);
    acc = Result.ScerevisiaeTests.Accuracy(i);
    mcc = Result.ScerevisiaeTests.MCC(i);
    
    fprintf(FID,format,'S. cerevisiae',type{i},biomass{i},sens,spec,acc,mcc);
end

%Reference information
fprintf(FID,format,'E. coli','iGSM','iJO1366',0.96,0.66,0.91,0.67);

%% Analysis KO performance 

dfile = 'Table_Fig5.tsv';
dcols = [255 70 0; ...
        170 255 0; ...
        4,80,255]/255;
dcols = dcols([3 1 2],:);
dcat = {'iGSM','BCM','RCM'};
%dcat = {'BCM','RCM','iGSM'};
    
    
reforg = 'E. coli'; % reference organism
vars = {'Sensitivity','Specificity','Accuracy','MCC'};
nv = length(vars);

warning off;
T = readtable(dfile,'Delimiter','\t','FileType','text','TreatAsEmpty','NA');
orgs = setdiff(unique(T.Organism),reforg); % organisms
warning on;

figure(1);
clf;

axh = zeros(nv,1);
axp = zeros(nv,4);

yaxlim = [0.5 length(orgs)+.5];

for z = 1:nv,
    axh(z) = subplot(2,5,z);
    axp(z,:) = get(gca,'Position');
    
    for z1=1:length(orgs),
        
        for z2 = 1:length(dcat),
            
            row = T(ismember(T.Organism,orgs{z1}) & ismember(T.ModelType,dcat{z2}), :);
            vals = row.(vars{z});
%            plot(vals,0*vals+z1+.1*(z2-2),'o','MarkerEdgeColor',dcols(z2,:),'MarkerFaceColor',dcols(z2,:));
            plot(vals,0*vals+z1+.1*(z2-2),'o','MarkerEdgeColor',[0 0 0],'MarkerFaceColor',dcols(z2,:),'MarkerSize',7);
%             plot(vals,0*vals+z1+.1*(z2-2),'o','MarkerEdgeColor',dcols(z2,:));
            hold on
        end
        
    end
    xlabel(vars{z});
    v = axis;
    
    if v(1)>0
        v(1)=0.5;
        set(gca,'XTick',v(1):.25:1);
    end
        
    axis([v(1) 1 yaxlim]);
    
    row = T(ismember(T.Organism,reforg),:);
    plot([1 1]*row.(vars{z}),yaxlim,'k--');
    
    if z==1,
        vorgs = orgs;
        for z1=1:length(orgs),
            vorgs{z1} = [orgs{z1} ' ']; %['{\it ' orgs{z1} '}'];
        end
        set(gca,'YTick',1:length(orgs),'YTickLabel',vorgs);
    else
        set(gca,'YTick',[]);
    end
end

% reduce distance between subplots
qp = [0; diff(axp(:,1))]*.1;
axp(:,1) = axp(:,1)-cumsum(qp);
for z = 1:nv,
    set(axh(z),'Position',axp(z,:));
end

% layout, legend, and print

hl = legend(upper(dcat),'Location','NorthOutside');
lp = get(hl,'Position');
set(hl,'Position',[0.97*(axp(end,1)+axp(end,3)) lp(2:4)],'FontSize',12);
legend boxoff;

print -depsc2 -loose fig-commgen-ko-performance.eps
print -dsvg -loose fig-commgen-ko-performance.svg
print -dpdf -loose fig-commgen-ko-performance.pdf
